@@ -15,7 +15,6 @@ from pyplan_core.cubepy.Helpers import Helpers
 from pyplan_core.classes.IOEngine import IOEngine
 from pyplan_core.classes.NodeInfo import NodeInfo
 from pyplan_core.classes.PyplanFunctions import Selector
-from pyplan_core.classes.XHelpers import XHelpers
 
 
 class BaseNode(object):
@@ -484,7 +483,7 @@ class BaseNode(object):
                     (lazy_end_time - lazy_start_time).total_seconds()
 
     def calculate(self, extraParams=None):
-        """Calculate result of node"""
+        """Calculate result of the node"""
 
         if not self.isCalc or self.nodeClass == "button" or self.nodeClass == "formnode":
             nodeIsCircular = self.isCircular()
@@ -558,23 +557,16 @@ class BaseNode(object):
                 localRes = {
                     "getNode": self._model.getNode,
                     "getCalcNode": self._getCalcNode,
-                    "cp": Helpers(self),
-                    "pp": XHelpers(self)
+                    "cp": Helpers(self)
                 }
                 if not extraParams is None:
                     for keyParam in extraParams:
                         localRes[keyParam] = extraParams[keyParam]
-
-                if self.identifier == "imports":
-                    # check for cubepy for fix new lib import
-                    if ", cubepy," in finalDef:
-                        finalDef = finalDef.replace(
-                            ", cubepy,", ", pyplan_core.cubepy as cubepy,")
-                else:
-                    customImports = self.model.getCustomImports()
-                    if customImports:
-                        for keyParam in customImports:
-                            localRes[keyParam] = customImports[keyParam]
+                
+                customImports = self.model.getCustomImports()
+                if customImports:
+                    for keyParam in customImports:
+                        localRes[keyParam] = customImports[keyParam]
 
                 try:
                     # execute node definition in supervised context
@@ -619,7 +611,6 @@ class BaseNode(object):
                     self.evaluationVersion = self.model.evaluationVersion
                 finally:
                     localRes["cp"].release()
-                    localRes["pp"].release()
                     localRes = None
                     self.sendEndCalcNode(from_circular_evaluator)
         else:
